@@ -12,9 +12,10 @@ const char * ftpStrerror(int ftpErrno);
 #define FTPERR_FILE_IO_ERROR         -7
 #define FTPERR_PASSIVE_ERROR         -8
 #define FTPERR_FAILED_DATA_CONNECT   -9
+#define FTPERR_FILE_NOT_FOUND        -10
 #define FTPERR_UNKNOWN               -100
 
-int ftpOpen(char * host, char * name, char * password, char * proxy);
+int ftpOpen(char * host, char * name, char * password, char * proxy, int port);
 int ftpGetFile(int sock, char * remotename, int dest);
 int ftpGetFileDesc(int sock, char * remotename);
 int ftpGetFileDone(int sock);
