@@ -1,4 +1,5 @@
-#include <alloca.h>
+#include "config.h"
+
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -10,7 +11,12 @@
 #include <sys/param.h>
 #include <unistd.h>
 
+#if HAVE_ALLOCA_H
+# include <alloca.h>
+#endif
+
 #include "lib/messages.h"
+#include "miscfn.h"
 #include "rpmlib.h"
 #include "query.h"
 #include "url.h"
@@ -23,33 +29,15 @@ static int queryHeader(Header h, char * chptr);
 static int queryArray(Header h, char ** chptrptr);
 static void escapedChar(char ch);
 static char * handleFormat(Header h, char * chptr, int * count, int arrayNum);
-static void showMatches(rpmdb db, dbIndexSet matches, int queryFlags, 
+static void showMatches(rpmdb db, dbiIndexSet matches, int queryFlags, 
 			char * queryFormat);
 static int findMatches(rpmdb db, char * name, char * version, char * release,
-		       dbIndexSet * matches);
+		       dbiIndexSet * matches);
 static void printFileInfo(char * name, unsigned int size, unsigned short mode,
 			  unsigned int mtime, unsigned short rdev,
 			  char * owner, char * group, int uid, int gid,
 			  char * linkto);
 
-static char * defaultQueryFormat = 
-	    "Name        : %-27{NAME} Distribution: %{DISTRIBUTION}\n"
-	    "Version     : %-27{VERSION}       Vendor: %{VENDOR}\n"
-	    "Release     : %-27{RELEASE}   Build Date: %{BUILDTIME:date}\n"
-	    "Install date: %-27{INSTALLTIME:date}   Build Host: %{BUILDHOST}\n"
-	    "Group       : %-27{GROUP}   Source RPM: %{SOURCERPM}\n"
-	    "Size        : %{SIZE}\n"
-	    "Summary     : %{SUMMARY}\n"
-	    "Description :\n%{DESCRIPTION}\n";
-static char * requiresQueryFormat = 
-	    "[%{REQUIRENAME} %{REQUIREFLAGS:depflags} %{REQUIREVERSION}\n]";
-static char * providesQueryFormat = "[%{PROVIDES}\n]";
-static char * scriptQueryFormat = 
-	    "preinstall script:\n%{RPMTAG_PREIN}\n"
-	    "postinstall script:\n%{RPMTAG_POSTIN}\n"
-	    "preuninstall script:\n%{RPMTAG_PREUN}\n"
-	    "postuninstall script:\n%{RPMTAG_POSTUN}\n";
-
 static int queryHeader(Header h, char * chptr) {
     int count = 0;
 
@@ -103,7 +91,7 @@ static int queryPartial(Header h, char ** chptrptr, int * cntptr,
 	    } else if (count != -1 && !*cntptr && !emptyItem){ 
 		*cntptr = count;
 	    } else if (count != -1 && *cntptr && count != *cntptr) {
-		printf("(parallel array size mismatch)");
+		fprintf(stderr, "(parallel array size mismatch)");
 		return 1;
 	    }
 	    break;
@@ -146,9 +134,10 @@ static char * handleFormat(Header h, char * chptr, int * cntptr,
     char how[20], format[20];
     int i, tagLength;
     char tag[100];
-    const struct rpmTagTableEntry * t;
+    const struct headerTagTableEntry * t;
     void * p;
     int type;
+    int showCount = 0;
     int notArray = 0;
     time_t dateint;
     struct tm * tstruct;
@@ -193,6 +182,7 @@ static char * handleFormat(Header h, char * chptr, int * cntptr,
 
     switch (*tagptr) {
 	case '=':	notArray = 1, tagptr++;	break;
+	case '#':	showCount = 1, tagptr++; break;
     }
 
     tagLength = chptr - tagptr;
@@ -217,53 +207,62 @@ static char * handleFormat(Header h, char * chptr, int * cntptr,
 	return NULL;
     }
  
-    if (!getEntry(h, t->val, &type, &p, &count) || !p) {
+    if (!headerGetEntry(h, t->val, &type, &p, &count) || !p) {
 	p = "(none)";
 	count = 1;
-	type = STRING_TYPE;
+	type = RPM_STRING_TYPE;
     } else if (notArray) {
 	*cntptr = -1;
+    } else if (showCount) {
+	i = count;
+	p = &i;
+	type = RPM_INT32_TYPE;
+	count = 1;
     } else if (count > 1 && (arrayNum == -1)) {
 	p = "(array)";
 	count = 1;
-	type = STRING_TYPE;
+	type = RPM_STRING_TYPE;
     } else if ((count - 1) < arrayNum && arrayNum != -1) {
 	p = "(past array end)";
 	count = 1;
-	type = STRING_TYPE;
+	type = RPM_STRING_TYPE;
     } else if (arrayNum != -1)
 	*cntptr = count;
 
     if (arrayNum == -1) arrayNum = 0;
 
     switch (type) {
-      case STRING_ARRAY_TYPE:
+      case RPM_STRING_ARRAY_TYPE:
 	strcat(format, "s");
 	printf(format, ((char **) p)[arrayNum]);
 	free(p);
 	break;
 
-      case STRING_TYPE:
+      case RPM_STRING_TYPE:
 	strcat(format, "s");
 	printf(format, p);
 	break;
 
-      case INT8_TYPE:
+      case RPM_CHAR_TYPE:
+      case RPM_INT8_TYPE:
 	strcat(format, "d");
 	printf(format, *(((int_8 *) p) + arrayNum));
 	break;
 
-      case INT16_TYPE:
+      case RPM_INT16_TYPE:
 	if (!strcmp(how, "perms") || !strcmp(how, "permissions")) {
 	    strcat(format, "s");
 	    printf(format, permsString(*(((int_16 *) p) + arrayNum)));
+	} else if (!strcmp(how, "octal")) {
+	    strcat(format, "#o");
+	    printf(format, *(((int_16 *) p) + arrayNum) & 0xFFFF);
 	} else {
 	    strcat(format, "d");
 	    printf(format, *(((int_16 *) p) + arrayNum));
 	}
 	break;
 
-      case INT32_TYPE:
+      case RPM_INT32_TYPE:
 	if (!strcmp(how, "date")) {
 	    strcat(format, "s");
 	    /* this is important if sizeof(int_32) ! sizeof(time_t) */
@@ -280,19 +279,22 @@ static char * handleFormat(Header h, char * chptr, int * cntptr,
 	    if (anint & RPMFILE_CONFIG)
 		strcat(buf, "c");
 	    printf(format, buf);
+	} else if (!strcmp(how, "octal")) {
+	    strcat(format, "#o");
+	    printf(format, *(((int_32 *) p) + arrayNum));
 	} else if (!strcmp(how, "perms") || !strcmp(how, "permissions")) {
 	    strcat(format, "s");
 	    printf(format, permsString(*(((int_32 *) p) + arrayNum)));
 	} else if (!strcmp(how, "depflags")) {
 	    buf[0] = '\0';
 	    anint = *(((int_32 *) p) + arrayNum);
-	    if (anint & REQUIRE_LESS) 
+	    if (anint & RPMSENSE_LESS) 
 		strcat(buf, "<");
-	    if (anint & REQUIRE_GREATER)
+	    if (anint & RPMSENSE_GREATER)
 		strcat(buf, ">");
-	    if (anint & REQUIRE_EQUAL)
+	    if (anint & RPMSENSE_EQUAL)
 		strcat(buf, "=");
-	    if (anint & REQUIRE_SERIAL)
+	    if (anint & RPMSENSE_SERIAL)
 		strcat(buf, "S");
 	
 	    strcat(format, "s");
@@ -331,7 +333,8 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
     char * prefix = NULL;
     char ** fileList, ** fileMD5List;
     char * fileStatesList;
-    char ** fileOwnerList, ** fileGroupList;
+    char ** fileOwnerList = NULL;
+    char ** fileGroupList = NULL;
     char ** fileLinktoList;
     int_32 * fileFlagsList, * fileMTimeList, * fileSizeList;
     int_32 * fileUIDList, * fileGIDList;
@@ -339,63 +342,56 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
     uint_16 * fileRdevList;
     int i;
 
-    getEntry(h, RPMTAG_NAME, &type, (void **) &name, &count);
-    getEntry(h, RPMTAG_VERSION, &type, (void **) &version, &count);
-    getEntry(h, RPMTAG_RELEASE, &type, (void **) &release, &count);
+    headerGetEntry(h, RPMTAG_NAME, &type, (void **) &name, &count);
+    headerGetEntry(h, RPMTAG_VERSION, &type, (void **) &version, &count);
+    headerGetEntry(h, RPMTAG_RELEASE, &type, (void **) &release, &count);
 
-    if (!queryFlags) {
+    if (!queryFormat && !queryFlags) {
 	printf("%s-%s-%s\n", name, version, release);
     } else {
-	if (queryFlags & QUERY_FOR_INFO) {
-	    if (!queryFormat) {
-		queryFormat = defaultQueryFormat;
-	    } 
-
+	if (queryFormat)
 	    queryHeader(h, queryFormat);
-	}
-
-	if (queryFlags & QUERY_FOR_PROVIDES) {
-	    if (isEntry(h, RPMTAG_PROVIDES))
-		queryHeader(h, providesQueryFormat);
-	}
-
-	if (queryFlags & QUERY_FOR_REQUIRES) {
-	    if (isEntry(h, RPMTAG_REQUIREFLAGS))
-		queryHeader(h, requiresQueryFormat);
-	}
 
 	if (queryFlags & QUERY_FOR_LIST) {
-	    if (!getEntry(h, RPMTAG_FILENAMES, &type, (void **) &fileList, 
+	    if (!headerGetEntry(h, RPMTAG_FILENAMES, &type, (void **) &fileList, 
 		 &count)) {
 		puts("(contains no files)");
 	    } else {
-		if (!getEntry(h, RPMTAG_FILESTATES, &type, 
+		if (!headerGetEntry(h, RPMTAG_FILESTATES, &type, 
 			 (void **) &fileStatesList, &count)) {
 		    fileStatesList = NULL;
 		}
-		getEntry(h, RPMTAG_FILEFLAGS, &type, 
+		headerGetEntry(h, RPMTAG_FILEFLAGS, &type, 
 			 (void **) &fileFlagsList, &count);
-		getEntry(h, RPMTAG_FILESIZES, &type, 
+		headerGetEntry(h, RPMTAG_FILESIZES, &type, 
 			 (void **) &fileSizeList, &count);
-		getEntry(h, RPMTAG_FILEMODES, &type, 
+		headerGetEntry(h, RPMTAG_FILEMODES, &type, 
 			 (void **) &fileModeList, &count);
-		getEntry(h, RPMTAG_FILEMTIMES, &type, 
+		headerGetEntry(h, RPMTAG_FILEMTIMES, &type, 
 			 (void **) &fileMTimeList, &count);
-		getEntry(h, RPMTAG_FILERDEVS, &type, 
+		headerGetEntry(h, RPMTAG_FILERDEVS, &type, 
 			 (void **) &fileRdevList, &count);
-		getEntry(h, RPMTAG_FILEUIDS, &type, 
-			 (void **) &fileUIDList, &count);
-		getEntry(h, RPMTAG_FILEGIDS, &type, 
-			 (void **) &fileGIDList, &count);
-		getEntry(h, RPMTAG_FILEUSERNAME, &type, 
-			 (void **) &fileOwnerList, &count);
-		getEntry(h, RPMTAG_FILEGROUPNAME, &type, 
-			 (void **) &fileGroupList, &count);
-		getEntry(h, RPMTAG_FILELINKTOS, &type, 
+		headerGetEntry(h, RPMTAG_FILELINKTOS, &type, 
 			 (void **) &fileLinktoList, &count);
-		getEntry(h, RPMTAG_FILEMD5S, &type, 
+		headerGetEntry(h, RPMTAG_FILEMD5S, &type, 
 			 (void **) &fileMD5List, &count);
 
+		if (!headerGetEntry(h, RPMTAG_FILEUIDS, &type, 
+			 (void **) &fileUIDList, &count)) {
+		    fileUIDList = NULL;
+		} else {
+		    headerGetEntry(h, RPMTAG_FILEGIDS, &type, 
+			     (void **) &fileGIDList, &count);
+		}
+
+		if (!headerGetEntry(h, RPMTAG_FILEUSERNAME, &type, 
+			 (void **) &fileOwnerList, &count)) {
+		    fileOwnerList = NULL;
+		} else {
+		    headerGetEntry(h, RPMTAG_FILEGROUPNAME, &type, 
+			     (void **) &fileGroupList, &count);
+		}
+
 		for (i = 0; i < count; i++) {
 		    if (!((queryFlags & QUERY_FOR_DOCS) || 
 			  (queryFlags & QUERY_FOR_CONFIG)) 
@@ -404,7 +400,7 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 			|| ((queryFlags & QUERY_FOR_CONFIG) && 
 			    (fileFlagsList[i] & RPMFILE_CONFIG))) {
 
-			if (!isVerbose())
+			if (!rpmIsVerbose())
 			    prefix ? fputs(prefix, stdout) : 0;
 
 			if (queryFlags & QUERY_FOR_STATE) {
@@ -414,10 +410,13 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 				    fputs("normal        ", stdout); break;
 				  case RPMFILE_STATE_REPLACED:
 				    fputs("replaced      ", stdout); break;
+				  case RPMFILE_STATE_NETSHARED:
+				    fputs("net shared    ", stdout); break;
 				  case RPMFILE_STATE_NOTINSTALLED:
 				    fputs("not installed ", stdout); break;
 				  default:
-				    fputs("(unknown)     ", stdout);
+				    printf("(unknown %3d) ", 
+					  fileStatesList[i]);
 				}
 			    } else {
 				fputs(    "(no state)    ", stdout);
@@ -432,9 +431,13 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 			    if (fileOwnerList)
 				printf("%s %s", fileOwnerList[i], 
 						fileGroupList[i]);
-			    else
+			    else if (fileUIDList)
 				printf("%d %d", fileUIDList[i], 
 						fileGIDList[i]);
+			    else {
+				rpmError(RPMERR_INTERNAL, "package has "
+					"neither file owner or id lists");
+			    }
 
 			    printf(" %s %s %d ", 
 				 fileFlagsList[i] & RPMFILE_CONFIG ? "1" : "0",
@@ -446,20 +449,24 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 			    else
 				printf("X\n");
 
-			} else if (!isVerbose()) {
+			} else if (!rpmIsVerbose()) {
 			    puts(fileList[i]);
 			} else if (fileOwnerList) 
 			    printFileInfo(fileList[i], fileSizeList[i],
 					  fileModeList[i], fileMTimeList[i],
 					  fileRdevList[i], fileOwnerList[i], 
-					  fileGroupList[i], fileUIDList[i], 
-					  fileGIDList[i], fileLinktoList[i]);
-			else
+					  fileGroupList[i], -1, 
+					  -1, fileLinktoList[i]);
+			else if (fileUIDList) {
 			    printFileInfo(fileList[i], fileSizeList[i],
 					  fileModeList[i], fileMTimeList[i],
 					  fileRdevList[i], NULL, 
 					  NULL, fileUIDList[i], 
 					  fileGIDList[i], fileLinktoList[i]);
+			} else {
+			    rpmError(RPMERR_INTERNAL, "package has "
+				    "neither file owner or id lists");
+			}
 		    }
 		}
 	    
@@ -470,10 +477,6 @@ static void printHeader(Header h, int queryFlags, char * queryFormat) {
 		if (fileGroupList) free(fileGroupList);
 	    }
 	}
-
-	if (queryFlags & QUERY_FOR_SCRIPTS) {
-	    queryHeader(h, scriptQueryFormat);
-	}
     }
 }
 
@@ -482,7 +485,7 @@ static char * permsString(int mode) {
 
     strcpy(perms, "-----------");
    
-    if (mode & S_ISVTX) perms[9] = 't';
+    if (mode & S_ISVTX) perms[10] = 't';
 
     if (mode & S_IRUSR) perms[1] = 'r';
     if (mode & S_IWUSR) perms[2] = 'w';
@@ -559,7 +562,7 @@ static void printFileInfo(char * name, unsigned int size, unsigned short mode,
 
     if (group) 
 	strncpy(groupfield, group, 8);
-    else
+    else 
 	sprintf(groupfield, "%-8d", gid);
 
     /* this is normally right */
@@ -592,14 +595,14 @@ static void printFileInfo(char * name, unsigned int size, unsigned short mode,
 		sizefield, timefield, namefield);
 }
 
-static void showMatches(rpmdb db, dbIndexSet matches, int queryFlags, 
+static void showMatches(rpmdb db, dbiIndexSet matches, int queryFlags, 
 			char * queryFormat) {
     int i;
     Header h;
 
     for (i = 0; i < matches.count; i++) {
 	if (matches.recs[i].recOffset) {
-	    message(MESS_DEBUG, "querying record number %d\n",
+	    rpmMessage(RPMMESS_DEBUG, "querying record number %d\n",
 			matches.recs[i].recOffset);
 	    
 	    h = rpmdbGetRecord(db, matches.recs[i].recOffset);
@@ -607,7 +610,7 @@ static void showMatches(rpmdb db, dbIndexSet matches, int queryFlags,
 		fprintf(stderr, "error: could not read database record\n");
 	    } else {
 		printHeader(h, queryFlags, queryFormat);
-		freeHeader(h);
+		headerFree(h);
 	    }
 	}
     }
@@ -621,34 +624,39 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
     int rc;
     int isSource;
     rpmdb db;
-    dbIndexSet matches;
+    dbiIndexSet matches;
     int recNumber;
     int retcode = 0;
     char *end = NULL;
     struct urlContext context;
-    int isUrl;
+    int isUrl = 0;
+    char path[255];
 
-    if (source != QUERY_SRPM && source != QUERY_RPM) {
+    if (source != QUERY_RPM) {
 	if (rpmdbOpen(prefix, &db, O_RDONLY, 0644)) {
 	    exit(1);
 	}
     }
 
     switch (source) {
-      case QUERY_SRPM:
       case QUERY_RPM:
 	if (urlIsURL(arg)) {
 	    isUrl = 1;
-	    fd = urlGetFd(arg, &context);
+	    if ((fd = urlGetFd(arg, &context)) < 0) {
+		fprintf(stderr, "open of %s failed: %s\n", arg, 
+			ftpStrerror(fd));
+	    }
+	} else if (!strcmp(arg, "-")) {
+	    fd = 0;
 	} else {
-	    isUrl = 0;
-	    fd = open(arg, O_RDONLY);
+	    if ((fd = open(arg, O_RDONLY)) < 0) {
+		fprintf(stderr, "open of %s failed: %s\n", arg, 
+			strerror(errno));
+	    }
 	}
 
-	if (fd < 0) {
-	    fprintf(stderr, "open of %s failed: %s\n", arg, strerror(errno));
-	} else {
-	    rc = pkgReadHeader(fd, &h, &isSource, NULL, NULL);
+	if (fd >= 0) {
+	    rc = rpmReadPackageHeader(fd, &h, &isSource, NULL, NULL);
 
 	    close(fd);
 	    if (isUrl) {
@@ -662,7 +670,7 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 						"queried\n");
 		    } else {
 			printHeader(h, queryFlags, queryFormat);
-			freeHeader(h);
+			headerFree(h);
 		    }
 		    break;
 		case 1:
@@ -687,19 +695,18 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 		return 1;
 	    }
 	    printHeader(h, queryFlags, queryFormat);
-	    freeHeader(h);
+	    headerFree(h);
 	    offset = rpmdbNextRecNum(db, offset);
 	}
 	break;
 
-      case QUERY_SGROUP:
       case QUERY_GROUP:
 	if (rpmdbFindByGroup(db, arg, &matches)) {
 	    fprintf(stderr, "group %s does not contain any packages\n", arg);
 	    retcode = 1;
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
-	    freeDBIndexRecord(matches);
+	    dbiFreeIndexRecord(matches);
 	}
 	break;
 
@@ -709,7 +716,7 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 	    retcode = 1;
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
-	    freeDBIndexRecord(matches);
+	    dbiFreeIndexRecord(matches);
 	}
 	break;
 
@@ -719,14 +726,12 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 	    retcode = 1;
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
-	    freeDBIndexRecord(matches);
+	    dbiFreeIndexRecord(matches);
 	}
 	break;
 
-      case QUERY_SPATH:
       case QUERY_PATH:
 	if (*arg != '/') {
-	    char path[255];
 	    if (realpath(arg, path) != NULL)
 		arg = path;
 	}
@@ -735,19 +740,17 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 	    retcode = 1;
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
-	    freeDBIndexRecord(matches);
+	    dbiFreeIndexRecord(matches);
 	}
 	break;
 
       case QUERY_DBOFFSET:
-
-      case QUERY_SPACKAGE:
 	recNumber = strtoul(arg, &end, 10);
 	if ((*end) || (end == arg) || (recNumber == ULONG_MAX)) {
 	    fprintf(stderr, "invalid package number: %s\n", arg);
 	    return 1;
 	}
-	message(MESS_DEBUG, "showing package: %d\n", recNumber);
+	rpmMessage(RPMMESS_DEBUG, "showing package: %d\n", recNumber);
 	h = rpmdbGetRecord(db, recNumber);
 
 	if (!h)  {
@@ -755,7 +758,7 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 	    retcode = 1;
 	} else {
 	    printHeader(h, queryFlags, queryFormat);
-	    freeHeader(h);
+	    headerFree(h);
 	}
 	break;
 
@@ -769,12 +772,12 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 	    fprintf(stderr, "error looking for package %s\n", arg);
 	} else {
 	    showMatches(db, matches, queryFlags, queryFormat);
-	    freeDBIndexRecord(matches);
+	    dbiFreeIndexRecord(matches);
 	}
 	break;
     }
    
-    if (source != QUERY_SRPM && source != QUERY_RPM) {
+    if (source != QUERY_RPM) {
 	rpmdbClose(db);
     }
 
@@ -784,7 +787,7 @@ int doQuery(char * prefix, enum querysources source, int queryFlags,
 /* 0 found matches */
 /* 1 no matches */
 /* 2 error */
-int findPackageByLabel(rpmdb db, char * arg, dbIndexSet * matches) {
+int findPackageByLabel(rpmdb db, char * arg, dbiIndexSet * matches) {
     char * localarg, * chptr;
     char * release;
     int rc;
@@ -821,7 +824,7 @@ int findPackageByLabel(rpmdb db, char * arg, dbIndexSet * matches) {
 /* 1 no matches */
 /* 2 error */
 int findMatches(rpmdb db, char * name, char * version, char * release,
-		dbIndexSet * matches) {
+		dbiIndexSet * matches) {
     int gotMatches;
     int rc;
     int i;
@@ -844,12 +847,12 @@ int findMatches(rpmdb db, char * name, char * version, char * release,
 	    h = rpmdbGetRecord(db, matches->recs[i].recOffset);
 	    if (!h) {
 		fprintf(stderr, "error: could not read database record\n");
-		freeDBIndexRecord(*matches);
+		dbiFreeIndexRecord(*matches);
 		return 2;
 	    }
 
-	    getEntry(h, RPMTAG_VERSION, &type, (void **) &pkgVersion, &count);
-	    getEntry(h, RPMTAG_RELEASE, &type, (void **) &pkgRelease, &count);
+	    headerGetEntry(h, RPMTAG_VERSION, &type, (void **) &pkgVersion, &count);
+	    headerGetEntry(h, RPMTAG_RELEASE, &type, (void **) &pkgRelease, &count);
 	    
 	    goodRelease = goodVersion = 1;
 
@@ -864,7 +867,7 @@ int findMatches(rpmdb db, char * name, char * version, char * release,
     }
 
     if (!gotMatches) {
-	freeDBIndexRecord(*matches);
+	dbiFreeIndexRecord(*matches);
 	return 1;
     }
     
@@ -872,7 +875,7 @@ int findMatches(rpmdb db, char * name, char * version, char * release,
 }
 
 void queryPrintTags(void) {
-    const struct rpmTagTableEntry * t;
+    const struct headerTagTableEntry * t;
     int i;
 
     for (i = 0, t = rpmTagTable; i < rpmTagTableSize; i++, t++) {
