@@ -36,7 +36,7 @@ int main(int argc, char **argv)
 	exit(1);
     }
 
-    rc = pkgReadHeader(fd, &hd, &isSource, NULL, NULL);
+    rc = rpmReadPackageHeader(fd, &hd, &isSource, NULL, NULL);
     if (rc == 1) {
 	fprintf(stderr, "argument is not an RPM package\n");
 	exit(1);
@@ -56,9 +56,13 @@ int main(int argc, char **argv)
         gzerror (stream, &zerror);
         if (zerror == Z_ERRNO){
 	    perror ("While uncompressing");
+	    gzclose(stream);
 	    return 1;
 	}
         fprintf (stderr, "rpm2cpio: zlib: %s error\n", zlib_err [-zerror]);
     }
+
+    gzclose(stream);
+
     return 0;
 }
